@@ -196,7 +196,7 @@ ReplaceScript=replace_in_files.pl
 
 # set version numbers in all Makefiles
 echo "set version numbers in all Makefiles ..."
-perl replace_in_files.pl -sR -f '=\d.\d.\d' -r =$CompilerVersionStr -m 'Makefile(.fpc)?' $FPCSrcDir/*
+perl replace_in_files.pl -sR -f 'version=\d.\d.\d' -r version=$CompilerVersionStr -m 'Makefile(.fpc)?' $FPCSrcDir/*
 
 
 #------------------------------------------------------------------------------
@@ -222,10 +222,11 @@ if [ "$PackageName" = "fpc" ]; then
   if test -z "$BINUTILSPREFIX"
   then
     # need up to date samplecfg that chains cross compiler additions
-    grep 'fpc-cross.cfg' $DebianInstallDir/lib/fpc/$FPCVersion/samplecfg &>/dev/null || \
+    SampleCfg=$DebianInstallDir/lib/fpc/$FPCVersion/samplecfg  
+    grep 'fpc-cross.cfg' "$SampleCfg" &>/dev/null || \
       sed -i -e "/^FPCPATH=/aFPCPARENT=\"\`dirname \"\$1\"\`\"
-;/^#ENDIF NEEDCROSSBINUTILS/i#include \$FPCPARENT/fpc-cross.cfg"  $DebianInstallDir/lib/fpc/$FPCVersion/samplecfg
-    else cat > $DebianInstallDir/lib/fpc/$FPCVersion/fpc${TARGET_SUFFIX}.cfg <<CROSS
+;/^#ENDIF NEEDCROSSBINUTILS/i#include \$FPCPARENT/fpc-cross.cfg"  "$SampleCfg"
+  else cat > $DebianInstallDir/lib/fpc/$FPCVersion/fpc${TARGET_SUFFIX}.cfg <<CROSS
 # Detect $TARGET compiles
 #IF \$fpc-target = $TARGET
  -XP$BINUTILSPREFIX
